@@ -27,6 +27,7 @@ class BaseSession:
 
     def __init__(self, session: Optional[Session] = None, timeout: int = 10,
                  verify_ssl: bool = True) -> None:
+        self._shared_session = bool(session)
         self._session = session
         self._ssl = verify_ssl
         self._timeout = timeout
@@ -108,9 +109,10 @@ if not BUILD_GCLOUD_REST:
     class AioSession(BaseSession):
         @property
         def session(self) -> aiohttp.ClientSession:
-            connector = aiohttp.TCPConnector(ssl=self._ssl)
-            self._session = self._session or aiohttp.ClientSession(
-                connector=connector, timeout=self._timeout)
+            if not self._session:
+                connector = aiohttp.TCPConnector(ssl=self._ssl)
+                self._session = aiohttp.ClientSession(connector=connector,
+                                                      timeout=self._timeout)
             return self._session
 
         async def post(self, url: str, headers: Dict[str, str],
@@ -170,7 +172,7 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         async def close(self) -> None:
-            if self._session:
+            if not self._shared_session and self._session:
                 await self._session.close()  # type: ignore[func-returns-value]
 
 
@@ -184,8 +186,9 @@ if BUILD_GCLOUD_REST:
 
         @property
         def session(self) -> Session:
-            self._session = self._session or Session()
-            self._session.verify = self._ssl
+            if not self._session:
+                self._session = Session()
+                self._session.verify = self._ssl
             return self._session
 
         # N.B.: none of these will be `async` in compiled form, but adding the
@@ -248,5 +251,5 @@ if BUILD_GCLOUD_REST:
             return resp
 
         async def close(self) -> None:
-            if self._session:
+            if not self._shared_session and self._session:
                 self._session.close()
